==============================
Models Noise
==============================

Noise
-------------------

.. autoclass:: exorad.models.noise.Noise
    :members:
    :undoc-members:
    :show-inheritance:

frame time
-------------------

.. automodule:: exorad.models.noise.frame_time
    :members:

multiaccum
-------------------

.. automodule:: exorad.models.noise.multiaccum
    :members:

photon_noise
-------------------

.. automodule:: exorad.models.noise.photon_noise
    :members:

